@@ -26,7 +26,11 @@ class MultiConstraintTest extends TestCase
      */
     protected $versionRequireEnd;
 
-    protected function setUp()
+    /**
+     * @before
+     * @return void
+     */
+    public function setUpTestCase()
     {
         $this->versionRequireStart = new Constraint('>', '1.0');
         $this->versionRequireEnd = new Constraint('<', '1.2');
@@ -154,7 +158,7 @@ class MultiConstraintTest extends TestCase
     /**
      * @return array<mixed>
      */
-    public function bounds()
+    public static function bounds()
     {
         return array(
             'all equal' => array(
@@ -226,7 +230,7 @@ class MultiConstraintTest extends TestCase
     /**
      * @return array<mixed>
      */
-    public function boundsIntegration()
+    public static function boundsIntegration()
     {
         return array(
             '^7.0' => array(
@@ -321,7 +325,7 @@ class MultiConstraintTest extends TestCase
     /**
      * @return array<mixed>
      */
-    public function multiConstraintOptimizations()
+    public static function multiConstraintOptimizations()
     {
         return array(
             'Test collapses contiguous' => array(
