@@ -14,6 +14,8 @@ namespace Composer\Semver;
 use Composer\Semver\Constraint\MatchAllConstraint;
 use Composer\Semver\Constraint\MultiConstraint;
 use Composer\Semver\Constraint\Constraint;
+use Exception;
+use LogicException;
 use PHPUnit\Framework\TestCase;
 
 class VersionParserTest extends TestCase
@@ -33,7 +35,7 @@ class VersionParserTest extends TestCase
     /**
      * @return array<mixed>
      */
-    public function numericAliasVersions()
+    public static function numericAliasVersions()
     {
         return array(
             array('0.x-dev', '0.'),
@@ -62,7 +64,7 @@ class VersionParserTest extends TestCase
     /**
      * @return array<mixed>
      */
-    public function successfulNormalizedVersions()
+    public static function successfulNormalizedVersions()
     {
         return array(
             'none' => array('1.0.0', '1.0.0.0'),
@@ -157,7 +159,7 @@ class VersionParserTest extends TestCase
     /**
      * @return array<mixed>
      */
-    public function failingNormalizedVersions()
+    public static function failingNormalizedVersions()
     {
         return array(
             'empty ' => array(''),
@@ -195,7 +197,9 @@ class VersionParserTest extends TestCase
      */
     public function testNormalizeFailsAndReportsAliasIssue($fullInput)
     {
-        preg_match('{^([^,\s#]+)(?:#[^ ]+)? +as +([^,\s]+)$}', $fullInput, $match);
+        if (!preg_match('{^([^,\s#]+)(?:#[^ ]+)? +as +([^,\s]+)$}', $fullInput, $match)) {
+            $this->fail($fullInput.' did not match the regex');
+        }
         $parser = new VersionParser();
         $parser->normalize($match[1], $fullInput);
         try {
@@ -208,7 +212,7 @@ class VersionParserTest extends TestCase
     /**
      * @return array<mixed>
      */
-    public function failingNormalizedVersionsWithBadAlias()
+    public static function failingNormalizedVersionsWithBadAlias()
     {
         return array(
             'Alias and caret' => array('1.0.0+foo as ^2.0'),
@@ -225,7 +229,9 @@ class VersionParserTest extends TestCase
      */
     public function testNormalizeFailsAndReportsAliaseeIssue($fullInput)
     {
-        preg_match('{^([^,\s#]+)(?:#[^ ]+)? +as +([^,\s]+)$}', $fullInput, $match);
+        if (!preg_match('{^([^,\s#]+)(?:#[^ ]+)? +as +([^,\s]+)$}', $fullInput, $match)) {
+            $this->fail($fullInput.' did not match the regex');
+        }
         $parser = new VersionParser();
         try {
             $parser->normalize($match[1], $fullInput);
@@ -238,7 +244,7 @@ class VersionParserTest extends TestCase
     /**
      * @return array<mixed>
      */
-    public function failingNormalizedVersionsWithBadAliasee()
+    public static function failingNormalizedVersionsWithBadAliasee()
     {
         return array(
             'Alias and caret' => array('^2.0 as 1.0.0+foo'),
@@ -264,7 +270,7 @@ class VersionParserTest extends TestCase
     /**
      * @return array<mixed>
      */
-    public function successfulNormalizedBranches()
+    public static function successfulNormalizedBranches()
     {
         return array(
             'parses x' => array('v1.x', '1.9999999.9999999.9999999-dev'),
@@ -333,7 +339,7 @@ class VersionParserTest extends TestCase
     /**
      * @return array<mixed>
      */
-    public function simpleConstraints()
+    public static function simpleConstraints()
     {
         return array(
             'match any' => array('*', new MatchAllConstraint()),
@@ -392,7 +398,7 @@ class VersionParserTest extends TestCase
     /**
      * @return array<mixed>
      */
-    public function wildcardConstraints()
+    public static function wildcardConstraints()
     {
         return array(
             array('v2.*', new Constraint('>=', '2.0.0.0-dev'), new Constraint('<', '3.0.0.0-dev')),
@@ -434,7 +440,7 @@ class VersionParserTest extends TestCase
     /**
      * @return array<mixed>
      */
-    public function tildeConstraints()
+    public static function tildeConstraints()
     {
         return array(
             array('~v1', new Constraint('>=', '1.0.0.0-dev'), new Constraint('<', '2.0.0.0-dev')),
@@ -481,7 +487,7 @@ class VersionParserTest extends TestCase
     /**
      * @return array<mixed>
      */
-    public function caretConstraints()
+    public static function caretConstraints()
     {
         return array(
             array('^v1', new Constraint('>=', '1.0.0.0-dev'), new Constraint('<', '2.0.0.0-dev')),
@@ -531,7 +537,7 @@ class VersionParserTest extends TestCase
     /**
      * @return array<mixed>
      */
-    public function hyphenConstraints()
+    public static function hyphenConstraints()
     {
         return array(
             array('v1 - v2', new Constraint('>=', '1.0.0.0-dev'), new Constraint('<', '3.0.0.0-dev')),
@@ -566,7 +572,7 @@ class VersionParserTest extends TestCase
     /**
      * @return array<mixed>
      */
-    public function constraintProvider()
+    public static function constraintProvider()
     {
         return array(
             // numeric branch
@@ -618,7 +624,7 @@ class VersionParserTest extends TestCase
     /**
      * @return array<mixed>
      */
-    public function multiConstraintProvider()
+    public static function multiConstraintProvider()
     {
         return array(
             array('>2.0,<=3.0'),
@@ -670,7 +676,7 @@ class VersionParserTest extends TestCase
     /**
      * @return array<mixed>
      */
-    public function multiConstraintProvider2()
+    public static function multiConstraintProvider2()
     {
         return array(
             array('>2.0,<2.0.5 | >2.0.6'),
@@ -724,7 +730,7 @@ class VersionParserTest extends TestCase
     /**
      * @return array<mixed>
      */
-    public function failingConstraints()
+    public static function failingConstraints()
     {
         return array(
             'empty ' => array(''),
@@ -783,7 +789,7 @@ class VersionParserTest extends TestCase
     /**
      * @return array<mixed>
      */
-    public function stabilityProvider()
+    public static function stabilityProvider()
     {
         return array(
             array('stable', '1'),
@@ -851,7 +857,7 @@ class VersionParserTest extends TestCase
     }
 
     /**
-     * @param class-string $class
+     * @param class-string<Exception> $class
      * @param string|null $message
      * @return void
      */
@@ -862,9 +868,10 @@ class VersionParserTest extends TestCase
             if ($message) {
                 $this->expectExceptionMessage($message);
             }
-        } else {
-            // @phpstan-ignore-next-line
+        } elseif (method_exists($this, 'setExpectedException')) {
             $this->setExpectedException($class, $message);
+        } else {
+            throw new LogicException('Expected method "expectException" or "setExpectedException" to exist.');
         }
     }
 }
